==> jena-arq-2.10.1-sources.jar: org/apache/jena/riot/web/TypedInputStreamHttp.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.riot.web;

import java.io.IOException ;
import java.io.InputStream ;

import org.apache.http.conn.ClientConnectionManager ;
import org.apache.jena.atlas.web.MediaType ;
import org.apache.jena.atlas.web.TypedInputStream ;

/** Type streams for HTTP connections - includes Apache HTTP client specific cleanup */
public class TypedInputStreamHttp extends TypedInputStream
{
    private ClientConnectionManager connectMgr ;

    TypedInputStreamHttp(InputStream input, MediaType mt, ClientConnectionManager connectMgr)
    {
        super(input, mt.getContentType(), mt.getCharset(), null) ;
        this.connectMgr = connectMgr ;
    }
    
    @Override
    public void close() throws IOException
    {
        super.close() ;
        if ( connectMgr != null )
            connectMgr.shutdown() ;
    }
    
}

==> jena-arq-2.11.1-sources.jar: org/apache/jena/riot/web/TypedInputStreamHttp.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.riot.web;

import java.io.IOException ;
import java.io.InputStream ;

import org.apache.http.conn.ClientConnectionManager ;
import org.apache.jena.atlas.web.MediaType ;
import org.apache.jena.atlas.web.TypedInputStream ;

/** Type streams for HTTP connections - includes Apache HTTP client specific cleanup */
public class TypedInputStreamHttp extends TypedInputStream
{
    private ClientConnectionManager connectMgr ;

    TypedInputStreamHttp(InputStream input, String contentType, ClientConnectionManager connectMgr)
    {
        this(input, MediaType.create(contentType), connectMgr) ;
    }
    
    TypedInputStreamHttp(InputStream input, MediaType mt, ClientConnectionManager connectMgr)
    {
        super(input, mt.getContentType(), mt.getCharset(), null) ;
        this.connectMgr = connectMgr ;
    }
    
    @Override
    public void close() throws IOException
    {
        super.close() ;
        if ( connectMgr != null )
            connectMgr.shutdown() ;
    }
    
}
